Structs
- Argument
- Arguments
( Argument+ )- Arguments
Definition ( InputValueDefinition+ )on field and directive definitions.- Ast
- AstBox
- A
BoxwithoutDrop, which stores its data in the arena allocator. - AstVec
- A
VecwithoutDrop, which stores its data in the arena allocator. - Boolean
Value - Default
Value = Value- Directive
- Directive
Definition - Directive
Extension - Directive
Location - Document
- Enum
Type Definition - Enum
Type Extension - Enum
Value - Enum
Value Definition - Enum
Values Definition { EnumValueDefinition+ }- Field
- Field
Definition - Fields
Definition { FieldDefinition+ }- Float
Value - Fragment
Definition - Fragment
Spread - Implements
Interfaces implements &? NamedType (& NamedType)*- Inline
Fragment - Input
Fields Definition { InputValueDefinition+ }- Input
Object Type Definition - Input
Object Type Extension - Input
Value Definition - IntValue
- Interface
Type Definition - Interface
Type Extension - List
Type - List
Value - Name
- Named
Type - NonNull
Type - Null
Value - Object
Field - Object
Type Definition - Object
Type Extension - Object
Value - Operation
Definition - Root
Operation Type Definition - Scalar
Type Definition - Scalar
Type Extension - Schema
Definition - Schema
Extension - Selection
Set - Span
- A half-open byte range into the source text.
- String
Value - Type
Condition on NamedType- Union
Member Types = |? NamedType (| NamedType)*- Union
Type Definition - Union
Type Extension - Variable
- Variable
Definition - Variable
Definitions ( VariableDefinition+ )on operations and fragments.