Definition

Enum Definition 

pub enum Definition<'a> {
Show 18 variants Operation(AstBox<'a, OperationDefinition<'a>>), Fragment(AstBox<'a, FragmentDefinition<'a>>), Directive(AstBox<'a, DirectiveDefinition<'a>>), DirectiveExtension(AstBox<'a, DirectiveExtension<'a>>), Schema(AstBox<'a, SchemaDefinition<'a>>), SchemaExtension(AstBox<'a, SchemaExtension<'a>>), ScalarType(AstBox<'a, ScalarTypeDefinition<'a>>), ScalarTypeExtension(AstBox<'a, ScalarTypeExtension<'a>>), ObjectType(AstBox<'a, ObjectTypeDefinition<'a>>), ObjectTypeExtension(AstBox<'a, ObjectTypeExtension<'a>>), InterfaceType(AstBox<'a, InterfaceTypeDefinition<'a>>), InterfaceTypeExtension(AstBox<'a, InterfaceTypeExtension<'a>>), UnionType(AstBox<'a, UnionTypeDefinition<'a>>), UnionTypeExtension(AstBox<'a, UnionTypeExtension<'a>>), EnumType(AstBox<'a, EnumTypeDefinition<'a>>), EnumTypeExtension(AstBox<'a, EnumTypeExtension<'a>>), InputObjectType(AstBox<'a, InputObjectTypeDefinition<'a>>), InputObjectTypeExtension(AstBox<'a, InputObjectTypeExtension<'a>>),
}

Variants



Operation(AstBox<'a, OperationDefinition<'a>>)



Fragment(AstBox<'a, FragmentDefinition<'a>>)



Directive(AstBox<'a, DirectiveDefinition<'a>>)



DirectiveExtension(AstBox<'a, DirectiveExtension<'a>>)



Schema(AstBox<'a, SchemaDefinition<'a>>)



SchemaExtension(AstBox<'a, SchemaExtension<'a>>)



ScalarType(AstBox<'a, ScalarTypeDefinition<'a>>)



ScalarTypeExtension(AstBox<'a, ScalarTypeExtension<'a>>)



ObjectType(AstBox<'a, ObjectTypeDefinition<'a>>)



ObjectTypeExtension(AstBox<'a, ObjectTypeExtension<'a>>)



InterfaceType(AstBox<'a, InterfaceTypeDefinition<'a>>)



InterfaceTypeExtension(AstBox<'a, InterfaceTypeExtension<'a>>)



UnionType(AstBox<'a, UnionTypeDefinition<'a>>)



UnionTypeExtension(AstBox<'a, UnionTypeExtension<'a>>)



EnumType(AstBox<'a, EnumTypeDefinition<'a>>)



EnumTypeExtension(AstBox<'a, EnumTypeExtension<'a>>)



InputObjectType(AstBox<'a, InputObjectTypeDefinition<'a>>)



InputObjectTypeExtension(AstBox<'a, InputObjectTypeExtension<'a>>)

Implementations

Source

impl<'a> Definition<'a>

pub fn name(&self) -> Option<&Name<'a>>

pub fn span(&self) -> Span

The source span of the definition, whichever variant it is.

When adding a new variant, remember to extend this match as well.