Definition

Enum Definition 

pub enum Definition<'a> {
Show 17 variants Operation(OperationDefinition<'a>), Fragment(FragmentDefinition<'a>), Directive(DirectiveDefinition<'a>), Schema(SchemaDefinition<'a>), SchemaExtension(SchemaExtension<'a>), ScalarType(ScalarTypeDefinition<'a>), ScalarTypeExtension(ScalarTypeExtension<'a>), ObjectType(ObjectTypeDefinition<'a>), ObjectTypeExtension(ObjectTypeExtension<'a>), InterfaceType(InterfaceTypeDefinition<'a>), InterfaceTypeExtension(InterfaceTypeExtension<'a>), UnionType(UnionTypeDefinition<'a>), UnionTypeExtension(UnionTypeExtension<'a>), EnumType(EnumTypeDefinition<'a>), EnumTypeExtension(EnumTypeExtension<'a>), InputObjectType(InputObjectTypeDefinition<'a>), InputObjectTypeExtension(InputObjectTypeExtension<'a>),
}

Variants



Operation(OperationDefinition<'a>)



Fragment(FragmentDefinition<'a>)



Directive(DirectiveDefinition<'a>)



Schema(SchemaDefinition<'a>)



SchemaExtension(SchemaExtension<'a>)



ScalarType(ScalarTypeDefinition<'a>)



ScalarTypeExtension(ScalarTypeExtension<'a>)



ObjectType(ObjectTypeDefinition<'a>)



ObjectTypeExtension(ObjectTypeExtension<'a>)



InterfaceType(InterfaceTypeDefinition<'a>)



InterfaceTypeExtension(InterfaceTypeExtension<'a>)



UnionType(UnionTypeDefinition<'a>)



UnionTypeExtension(UnionTypeExtension<'a>)



EnumType(EnumTypeDefinition<'a>)



EnumTypeExtension(EnumTypeExtension<'a>)



InputObjectType(InputObjectTypeDefinition<'a>)



InputObjectTypeExtension(InputObjectTypeExtension<'a>)

Implementations

Source

impl<'a> Definition<'a>

pub fn name(&self) -> Option<&Name<'a>>

pub fn span(&self) -> Span

The source span of the definition, whichever variant it is.

When adding a new variant, remember to extend this match as well.